@@ -2,6 +2,10 @@
 #'
 #' @keywords internal
 "_PACKAGE"
+
+#' @importFrom rlang .data
+NULL
+
 ## CRAN Note avoidance.
 if (getRversion() >= "2.15.1") {
   utils::globalVariables("i")
